Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1125)

Unified Diff: ppapi/native_client/src/trusted/plugin/arch_mips/sandbox_isa.cc

Issue 152133007: [MIPS] Support for MIPS PNaCl in PPAPI (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Rebase. Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/native_client/src/trusted/plugin/arch_mips/sandbox_isa.cc
diff --git a/ppapi/native_client/src/trusted/plugin/arch_arm/sandbox_isa.cc b/ppapi/native_client/src/trusted/plugin/arch_mips/sandbox_isa.cc
similarity index 79%
copy from ppapi/native_client/src/trusted/plugin/arch_arm/sandbox_isa.cc
copy to ppapi/native_client/src/trusted/plugin/arch_mips/sandbox_isa.cc
index 108f49be22689bef0a0372247fbadd846a24d8a7..17471e512d4374844006bb2edcad30d9553ffe98 100644
--- a/ppapi/native_client/src/trusted/plugin/arch_arm/sandbox_isa.cc
+++ b/ppapi/native_client/src/trusted/plugin/arch_mips/sandbox_isa.cc
@@ -5,14 +5,14 @@
#include "ppapi/native_client/src/trusted/plugin/nexe_arch.h"
namespace {
// The list of supported ISA strings for ARM. See issue:
// http://code.google.com/p/nativeclient/issues/detail?id=1040 for more
// information. Note that these string are to be case-insensitive compared.
-const char* const kNexeArchARM = "arm";
+const char* const kNexeArchMIPS = "mips32";
} // namespace
namespace plugin {
const char* GetSandboxISA() {
- return kNexeArchARM;
+ return kNexeArchMIPS;
}
} // namespace plugin
@@ -5,14 +5,14 @@
#include "ppapi/native_client/src/trusted/plugin/nexe_arch.h"
namespace {
-// The list of supported ISA strings for ARM. See issue:
+// The list of supported ISA strings for MIPS. See issue:
// http://code.google.com/p/nativeclient/issues/detail?id=1040 for more
// information. Note that these string are to be case-insensitive compared.

Powered by Google App Engine
This is Rietveld 408576698